@@ -1,3 +1,10 @@
+#' @keywords internal
+"_PACKAGE"
+
+## usethis namespace: start
+## usethis namespace: end
+NULL
+
 #' Reproject data from source to target coordinate system.
 #'
 #' reproj provides helpers for easily reprojecting generic data, by depending
@@ -6,8 +13,7 @@
 #' The function `reproj` is designed to take an input data set `x` and then a
 #' `target` coordinate system specification. The `source` argument is not positional
 #' (must be named) and must be provided.
-#' Currently the coordinate system may be a 'PROJ string' or 'EPSG code' either
-#' as  a number or text.
+#' The coordinate system string may be anything accepted by the PROJ library (libproj). 
 #'
 #' Methods are provided for data frame and matrix, add S3 methods for
 #' you classes in your own package. For classed objects, or objects with a known
@@ -22,5 +28,4 @@
 #' functional this option can be set to true so that reproj falls-back to
 #' use the proj4 package instead.
 #' @name reproj-package
-#' @docType package
 NULL
