@@ -1,8 +1,15 @@
+err <- try(proj4::ptransform(cbind(0, 0), "OGC:CRS84", "+proj=laea"), silent = TRUE)
+if (inherits(err, "try-error")) {
+  df <- "+proj=longlat +datum=WGS84"
+} else {
+  df <- "OGC:CRS84"
+}
+
 reproj_default_options <- function() {
   list(
   reproj.mock.noproj6 = FALSE,
   reproj.assume.longlat = TRUE,
-  reproj.default.longlat = "+proj=longlat +datum=WGS84 +no_defs"
+  reproj.default.longlat = df
 )}
 
 .onLoad <- function(libname, pkgname) {
